# FastAPI Example

This example shows how to integrate [FastAPI](https://github.com/fastapi/fastapi/) with [openapipages](https://github.com/hasansezertasan/openapipages).

## How to run this example

Clone the repository and navigate to this example:

```shell
git clone https://github.com/hasansezertasan/openapipages.git
cd openapipages/examples/fastapi
```

> This example uses [`uv`](https://docs.astral.sh/uv/) to manage its dependencies and developer environment.

Run the example using `uv`, which will manage the environment and dependencies automatically:

```shell
uv run main.py
```
